@@ -105,6 +105,8 @@ class Preprocessor(BasePreprocessor):
                             api_dict['spec'],
                             self.offline,
                             api_dict.get('endpoint_prefix', ''),
+                            api_dict.get('login'),
+                            api_dict.get('password'),
                         )
                     except WrongModeError:
                         self._warning(
@@ -123,6 +125,8 @@ class Preprocessor(BasePreprocessor):
                             api_dict['spec'],
                             self.offline,
                             api_dict.get('endpoint_prefix', ''),
+                            api_dict.get('login'),
+                            api_dict.get('password'),
                         )
                     except WrongModeError:
                         self._warning(
@@ -136,7 +140,9 @@ class Preprocessor(BasePreprocessor):
                                      DEFAULT_HEADER_TEMPLATE),
                         self.offline,
                         api_dict.get('site_backend', 'slate'),
-                        api_dict.get('endpoint_prefix', '')
+                        api_dict.get('endpoint_prefix', ''),
+                        api_dict.get('login'),
+                        api_dict.get('password'),
                     )
                 self.apis[api.lower()] = api_obj
                 if api_dict.get('default', False) and self.default_api is None:
@@ -215,9 +221,13 @@ class Preprocessor(BasePreprocessor):
             else:
                 raise GenURLError(f'Cannot find method {ref.verb} {ref.command} in {api.name}.')
         else:
-            prefixes = [*self.options.get('API', {}).keys(), self.options['prefix_to_ignore']]
-            raise GenURLError(f'"{ref.prefix}" is a wrong prefix. Should be one of: '
-                              f'{", ".join(prefixes)}.')
+            config_prefixes = [*self.options.get('API', {}).keys(), self.options['prefix_to_ignore']]
+            set_up_prefixes = [*self.apis.keys(), self.options['prefix_to_ignore'].lower()]
+            if ref.prefix in config_prefixes:
+                raise GenURLError(f'API for prefix "{ref.prefix}" is not properly configured')
+            else:
+                raise GenURLError(f'"{ref.prefix}" is a wrong prefix. Should be one of: '
+                                  f'{", ".join(set_up_prefixes)}.')
 
     def assume_api(self, ref: Reference) -> API:
         '''
